@@ -63,7 +63,8 @@ class Eaves:
         self.screen: Optional[Surface] = None
         self.current_status: str = 'main_menu'
         self.type_handlers = {
-            str: lambda status: exec('self.current_status = status')
+            str: lambda status: exec('self.current_status = status'),
+            tuple[pygame_menu.Menu, list[Event]]: self.handle_menus
         }
         self.fps_cap: float = 60.0
         self.clock = pygame.time.Clock()
@@ -77,6 +78,11 @@ class Eaves:
     def fps(self) -> float:
         return self.clock.get_fps()
 
+    def handle_menus(self, objs: tuple[pygame_menu.Menu, list[Event]]) -> None:
+        menu, events = objs
+        menu.update(events)
+        menu.draw(self.screen) # type: ignore
+
     def load_files(self, files: list[str]) -> None:
         self.handlers_to_load = files
 
